==> pywrike-1.90.tar.gz: pywrike-1.90/PyWrike/__init__.py <==
# __init__.py
from .gateways.oauth2gateway1 import OAuth2Gateway1
from .wrike import (
    validate_token,
    authenticate_with_oauth2,
    get_folder_id_by_name,
    create_wrike_project,
    create_wrike_folder,
    delete_wrike_project,
    delete_wrike_folder,
    get_space_id_by_name,
    get_folder_id_by_path,
    get_folder_id_in_space_by_name,
    get_all_folders_in_space,
    get_all_tasks_in_space,
    get_or_create_subfolder,
    create_subfolder,
    get_tasks_in_space,
    get_tasks_by_folder_id,
    get_task_id_by_title,
    get_responsible_id_by_name_and_email,
    cache_subtasks_from_tasks,
    get_custom_fields_by_space,
    map_excel_headings_to_custom_fields,
    create_task,
    get_task_by_id,
    update_task_with_tags,
    update_subtask_with_parent,
    create_task_in_folder,
    get_subtasks_by_task_id,
    create_subtask_in_parent_task,
    create_subtask,
    read_config_from_excel,
    get_wrike_space_id,
    get_space_details,
    create_new_space,
    get_custom_fields,
    create_custom_field,
    map_custom_fields,
    get_folders_in_space,
    get_folder_by_id,
    get_titles_hierarchy,
    get_tasks_in_folder,
    get_task_details,
    find_task_across_folders,
    create_or_update_task,
    create_folders_recursively,
    get_task_key_by_id,
    create_tasks,
    create_folder,
    create_folder_in_space,
    get_folder_id_by_paths,
    get_folder_in_space_by_name,
    get_subfolder_id_by_name,
    get_all_tasks_in_folder,
    get_task_id_by_titles,
    create_task_folder,
    get_task_detail,
    retry_request,
    get_all_spaces,
    get_space_id_from_name,
    get_all_folders,
    get_tasks_details,
    get_tasks_for_folder,
    get_all_subtask_ids,
    clean_html,
    get_user_details,
    get_custom_statuses,
    create_custom_status_mapping,
    create_custom_field_mapping,
    save_to_json,
    create_folder_by_path,
    create_folders,
    map_custom_fields_propagate,
    get_all_folders_json,
    get_tasks_in_folder_json,
    get_subtask_details,
    create_folder_or_project,
    create_subtask_propagate,
    create_task_folder_propagate
)

# Optionally, you can define `__all__` to control what gets imported with a wildcard (*) import
__all__ = [
    "validate_token",
    "authenticate_with_oauth2",
    "get_folder_id_by_name",
    "create_wrike_project",
    "create_wrike_folder",
    " delete_wrike_project",
    "delete_wrike_folder",
    "get_space_id_by_name",
    "get_folder_id_by_path",
    "get_folder_id_in_space_by_name",
    "get_all_folders_in_space",
    "get_all_tasks_in_space",
    "get_or_create_subfolder",
    "create_subfolder",
    "get_tasks_in_space",
    "get_tasks_by_folder_id",
    "get_task_id_by_title",
    "get_responsible_id_by_name_and_email",
    "cache_subtasks_from_tasks",
    "get_custom_fields_by_space",
    "map_excel_headings_to_custom_fields",
    "create_task",
    "get_task_by_id",
    "update_task_with_tags",
    "update_subtask_with_parent",
    "create_task_in_folder",
    "get_subtasks_by_task_id",
    "create_subtask_in_parent_task",
    "create_subtask",
    "read_config_from_excel",
    "get_wrike_space_id",
    "get_space_details",
    "create_new_space",
    "get_custom_fields",
    "create_custom_field",
    "map_custom_fields",
    "get_folders_in_space",
    "get_folder_by_id",
    "get_titles_hierarchy",
    "get_tasks_in_folder",
    "get_task_details",
    "find_task_across_folders",
    "create_or_update_task",
    "create_folders_recursively",
    "get_task_key_by_id",
    "create_tasks",
    "create_folder",
    "create_folder_in_space",
    "get_folder_id_by_paths",
    "get_folder_in_space_by_name",
    "get_subfolder_id_by_name",
    "get_all_tasks_in_folder",
    "get_task_id_by_titles",
    "create_task_folder",
    "get_task_detail",
    "retry_request",
    "get_all_spaces",
    "get_space_id_from_name",
    "get_all_folders",
    "get_tasks_details",
    "get_tasks_for_folder",
    "get_all_subtask_ids",
    "clean_html",
    "get_user_details",
    "get_custom_statuses",
    "create_custom_status_mapping",
    "create_custom_field_mapping",
    "save_to_json",
    "create_folder_by_path",
    "create_folders",
    "map_custom_fields_propagate",
    "get_all_folders_json",
    "get_tasks_in_folder_json",
    "get_subtask_details",
    "create_folder_or_project",
    "create_subtask_propagate",
    "create_task_folder_propagate"
]

==> pywrike-1.954.tar.gz: pywrike-1.954/PyWrike/__init__.py <==
# __init__.py
from .gateways.oauth2gateway1 import OAuth2Gateway1
from .wrike import (
    validate_token,
    authenticate_with_oauth2,
    get_folder_id_by_name,
    create_wrike_project,
    create_wrike_folder,
    delete_wrike_project,
    delete_wrike_folder,
    get_space_id_by_name,
    get_folder_id_by_path,
    get_folder_id_in_space_by_name,
    get_all_folders_in_space,
    get_all_tasks_in_space,
    get_or_create_subfolder,
    create_subfolder,
    get_tasks_in_space,
    get_tasks_by_folder_id,
    get_task_id_by_title,
    get_responsible_id_by_name_and_email,
    cache_subtasks_from_tasks,
    get_custom_fields_by_space,
    map_excel_headings_to_custom_fields,
    create_task,
    get_task_by_id,
    update_task_with_tags,
    update_subtask_with_parent,
    create_task_in_folder,
    get_subtasks_by_task_id,
    create_subtask_in_parent_task,
    create_subtask,
    read_config_from_excel,
    get_wrike_space_id,
    get_space_details,
    create_new_space,
    get_custom_fields,
    create_custom_field,
    map_custom_fields,
    get_folders_in_space,
    get_folder_by_id,
    get_titles_hierarchy,
    get_tasks_in_folder,
    get_task_details,
    find_task_across_folders,
    create_or_update_task,
    create_folders_recursively,
    get_task_key_by_id,
    create_tasks,
    create_folder,
    create_folder_in_space,
    get_folder_id_by_paths,
    get_folder_in_space_by_name,
    get_subfolder_id_by_name,
    get_all_tasks_in_folder,
    get_task_id_by_titles,
    create_task_folder,
    get_task_detail,
    retry_request,
    get_all_spaces,
    get_space_id_from_name,
    get_all_folders,
    get_tasks_details,
    get_tasks_for_folder,
    get_all_subtask_ids,
    clean_html,
    get_user_details,
    get_custom_statuses,
    create_custom_status_mapping,
    create_custom_field_mapping,
    save_to_json,
    create_folder_by_path,
    create_folders,
    map_custom_fields_propagate,
    get_all_folders_json,
    get_tasks_in_folder_json,
    get_subtask_details,
    create_folder_or_project,
    create_subtask_propagate,
    create_task_folder_propagate,
    get_unique_custom_field_titles,
    process_subtasks,
    process_space_data,
    get_filtered_custom_fields,
    get_custom_fields_json,
    get_workflows,
    process_space,
    get_subtask_details_json,
    delete_wrike_folder_by_id,
    get_folder_id_by_paths_2
)

# Optionally, you can define `__all__` to control what gets imported with a wildcard (*) import
__all__ = [
    "validate_token",
    "authenticate_with_oauth2",
    "get_folder_id_by_name",
    "create_wrike_project",
    "create_wrike_folder",
    "delete_wrike_project",
    "delete_wrike_folder",
    "get_space_id_by_name",
    "get_folder_id_by_path",
    "get_folder_id_in_space_by_name",
    "get_all_folders_in_space",
    "get_all_tasks_in_space",
    "get_or_create_subfolder",
    "create_subfolder",
    "get_tasks_in_space",
    "get_tasks_by_folder_id",
    "get_task_id_by_title",
    "get_responsible_id_by_name_and_email",
    "cache_subtasks_from_tasks",
    "get_custom_fields_by_space",
    "map_excel_headings_to_custom_fields",
    "create_task",
    "get_task_by_id",
    "update_task_with_tags",
    "update_subtask_with_parent",
    "create_task_in_folder",
    "get_subtasks_by_task_id",
    "create_subtask_in_parent_task",
    "create_subtask",
    "read_config_from_excel",
    "get_wrike_space_id",
    "get_space_details",
    "create_new_space",
    "get_custom_fields",
    "create_custom_field",
    "map_custom_fields",
    "get_folders_in_space",
    "get_folder_by_id",
    "get_titles_hierarchy",
    "get_tasks_in_folder",
    "get_task_details",
    "find_task_across_folders",
    "create_or_update_task",
    "create_folders_recursively",
    "get_task_key_by_id",
    "create_tasks",
    "create_folder",
    "create_folder_in_space",
    "get_folder_id_by_paths",
    "get_folder_in_space_by_name",
    "get_subfolder_id_by_name",
    "get_all_tasks_in_folder",
    "get_task_id_by_titles",
    "create_task_folder",
    "get_task_detail",
    "retry_request",
    "get_all_spaces",
    "get_space_id_from_name",
    "get_all_folders",
    "get_tasks_details",
    "get_tasks_for_folder",
    "get_all_subtask_ids",
    "clean_html",
    "get_user_details",
    "get_custom_statuses",
    "create_custom_status_mapping",
    "create_custom_field_mapping",
    "save_to_json",
    "create_folder_by_path",
    "create_folders",
    "map_custom_fields_propagate",
    "get_all_folders_json",
    "get_tasks_in_folder_json",
    "get_subtask_details",
    "create_folder_or_project",
    "create_subtask_propagate",
    "create_task_folder_propagate",
    "get_unique_custom_field_titles",
    "process_subtasks",
    "process_space_data",
    "get_filtered_custom_fields",
    "get_custom_fields_json",
    "get_workflows",
    "process_space",
    "get_subtask_details_json",
    "delete_wrike_folder_by_id",
    "get_folder_id_by_paths_2"
]
